==> libkdegames-23.04.3-1-aarch64.pkg.tar.xz: usr/include/KF5/KDEGames/libkdegamesprivate/libkdegamesprivate_export.h <==

#ifndef KDEGAMESPRIVATE_EXPORT_H
#define KDEGAMESPRIVATE_EXPORT_H

#ifdef KDEGAMESPRIVATE_STATIC_DEFINE
#  define KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_NO_EXPORT
#else
#  ifndef KDEGAMESPRIVATE_EXPORT
#    ifdef KF5KDEGamesPrivate_EXPORTS
        /* We are building this library */
#      define KDEGAMESPRIVATE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KDEGAMESPRIVATE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KDEGAMESPRIVATE_NO_EXPORT
#    define KDEGAMESPRIVATE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED
#  define KDEGAMESPRIVATE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT
#  define KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT
#  define KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KDEGAMESPRIVATE_NO_DEPRECATED
#    define KDEGAMESPRIVATE_NO_DEPRECATED
#  endif
#endif

#define KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KDEGAMESPRIVATE_NO_DEPRECATED)
#  undef KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT
#elif defined(KDEGAMESPRIVATE_NO_DEPRECATED_WARNINGS)
#  define KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT
#else
#  define KDEGAMESPRIVATE_DEPRECATED KDEGAMESPRIVATE_DECL_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KDEGAMESPRIVATE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KDEGAMESPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KDEGAMESPRIVATE_NO_DEPRECATED
#  define KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x70500
#endif
#ifdef KDEGAMESPRIVATE_NO_DEPRECATED_WARNINGS
#  define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE
#  ifdef KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE 0x70500
#  endif
#endif

#ifndef KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KDEGAMESPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x30200
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_3_2(text) KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text)
#else
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_3_2(text)
#endif

#if KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x40900
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_4_9(text) KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text)
#else
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_4_9(text)
#endif

#if KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x70300
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_7_3(text) KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text)
#else
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_7_3(text)
#endif

#if KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x70400
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_7_4(text) KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text)
#else
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_7_4(text)
#endif
#define KDEGAMESPRIVATE_DEPRECATED_VERSION_3(minor, text)      KDEGAMESPRIVATE_DEPRECATED_VERSION_3_##minor(text)
#define KDEGAMESPRIVATE_DEPRECATED_VERSION_4(minor, text)      KDEGAMESPRIVATE_DEPRECATED_VERSION_4_##minor(text)
#define KDEGAMESPRIVATE_DEPRECATED_VERSION_7(minor, text)      KDEGAMESPRIVATE_DEPRECATED_VERSION_7_##minor(text)
#define KDEGAMESPRIVATE_DEPRECATED_VERSION(major, minor, text) KDEGAMESPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KDEGAMESPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDEGAMESPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KDEGAMESPRIVATE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KDEGAMESPRIVATE_DEPRECATED_VERSION(major, minor, text)
#  define KDEGAMESPRIVATE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDEGAMESPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KDEGAMESPRIVATE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KDEGAMESPRIVATE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KDEGAMESPRIVATE_EXPORT_H */

==> libkdegames-23.08.5-1-aarch64.pkg.tar.xz: usr/include/KF5/KDEGames/libkdegamesprivate/libkdegamesprivate_export.h <==

#ifndef KDEGAMESPRIVATE_EXPORT_H
#define KDEGAMESPRIVATE_EXPORT_H

#ifdef KDEGAMESPRIVATE_STATIC_DEFINE
#  define KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_NO_EXPORT
#else
#  ifndef KDEGAMESPRIVATE_EXPORT
#    ifdef KDEGamesPrivate_EXPORTS
        /* We are building this library */
#      define KDEGAMESPRIVATE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KDEGAMESPRIVATE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KDEGAMESPRIVATE_NO_EXPORT
#    define KDEGAMESPRIVATE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED
#  define KDEGAMESPRIVATE_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT
#  define KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED
#endif

#ifndef KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT
#  define KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KDEGAMESPRIVATE_NO_DEPRECATED
#    define KDEGAMESPRIVATE_NO_DEPRECATED
#  endif
#endif

#define KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KDEGAMESPRIVATE_NO_DEPRECATED)
#  undef KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT
#elif defined(KDEGAMESPRIVATE_NO_DEPRECATED_WARNINGS)
#  define KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_NO_EXPORT
#else
#  define KDEGAMESPRIVATE_DEPRECATED KDEGAMESPRIVATE_DECL_DEPRECATED
#  define KDEGAMESPRIVATE_DEPRECATED_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED_EXPORT
#  define KDEGAMESPRIVATE_DEPRECATED_NO_EXPORT KDEGAMESPRIVATE_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KDEGAMESPRIVATE_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KDEGAMESPRIVATE_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KDEGAMESPRIVATE_NO_DEPRECATED
#  define KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x70500
#endif
#ifdef KDEGAMESPRIVATE_NO_DEPRECATED_WARNINGS
#  define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE
#  ifdef KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE 0x70500
#  endif
#endif

#ifndef KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KDEGAMESPRIVATE_DEPRECATED
#  define KDEGAMESPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KDEGAMESPRIVATE_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KDEGAMESPRIVATE_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x30200
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_3_2(text) KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text)
#else
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_3_2(text)
#endif

#if KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x40900
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_4_9(text) KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text)
#else
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_4_9(text)
#endif

#if KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x70300
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_7_3(text) KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text)
#else
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_7_3(text)
#endif

#if KDEGAMESPRIVATE_DEPRECATED_WARNINGS_SINCE >= 0x70400
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_7_4(text) KDEGAMESPRIVATE_DECL_DEPRECATED_TEXT(text)
#else
#  define KDEGAMESPRIVATE_DEPRECATED_VERSION_7_4(text)
#endif
#define KDEGAMESPRIVATE_DEPRECATED_VERSION_3(minor, text)      KDEGAMESPRIVATE_DEPRECATED_VERSION_3_##minor(text)
#define KDEGAMESPRIVATE_DEPRECATED_VERSION_4(minor, text)      KDEGAMESPRIVATE_DEPRECATED_VERSION_4_##minor(text)
#define KDEGAMESPRIVATE_DEPRECATED_VERSION_7(minor, text)      KDEGAMESPRIVATE_DEPRECATED_VERSION_7_##minor(text)
#define KDEGAMESPRIVATE_DEPRECATED_VERSION(major, minor, text) KDEGAMESPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KDEGAMESPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDEGAMESPRIVATE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KDEGAMESPRIVATE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KDEGAMESPRIVATE_DEPRECATED_VERSION(major, minor, text)
#  define KDEGAMESPRIVATE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDEGAMESPRIVATE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KDEGAMESPRIVATE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KDEGAMESPRIVATE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KDEGAMESPRIVATE_EXPORT_H */
